@@ -1,9 +1,15 @@
 import secrets
 
-from sqlalchemy import Column, String, Text, Integer
-from authlib.common.encoding import json_loads, json_dumps
+from sqlalchemy import Column
+from sqlalchemy import Integer
+from sqlalchemy import String
+from sqlalchemy import Text
+
+from authlib.common.encoding import json_dumps
+from authlib.common.encoding import json_loads
 from authlib.oauth2.rfc6749 import ClientMixin
-from authlib.oauth2.rfc6749 import scope_to_list, list_to_scope
+from authlib.oauth2.rfc6749 import list_to_scope
+from authlib.oauth2.rfc6749 import scope_to_list
 
 
 class OAuth2ClientMixin(ClientMixin):
@@ -11,7 +17,7 @@ class OAuth2ClientMixin(ClientMixin):
     client_secret = Column(String(120))
     client_id_issued_at = Column(Integer, nullable=False, default=0)
     client_secret_expires_at = Column(Integer, nullable=False, default=0)
-    _client_metadata = Column('client_metadata', Text)
+    _client_metadata = Column("client_metadata", Text)
 
     @property
     def client_info(self):
@@ -29,81 +35,80 @@ class OAuth2ClientMixin(ClientMixin):
 
     @property
     def client_metadata(self):
-        if 'client_metadata' in self.__dict__:
-            return self.__dict__['client_metadata']
+        if "client_metadata" in self.__dict__:
+            return self.__dict__["client_metadata"]
         if self._client_metadata:
             data = json_loads(self._client_metadata)
-            self.__dict__['client_metadata'] = data
+            self.__dict__["client_metadata"] = data
             return data
         return {}
 
     def set_client_metadata(self, value):
         self._client_metadata = json_dumps(value)
-        if 'client_metadata' in self.__dict__:
-            del self.__dict__['client_metadata']
+        if "client_metadata" in self.__dict__:
+            del self.__dict__["client_metadata"]
 
     @property
     def redirect_uris(self):
-        return self.client_metadata.get('redirect_uris', [])
+        return self.client_metadata.get("redirect_uris", [])
 
     @property
     def token_endpoint_auth_method(self):
         return self.client_metadata.get(
-            'token_endpoint_auth_method',
-            'client_secret_basic'
+            "token_endpoint_auth_method", "client_secret_basic"
         )
 
     @property
     def grant_types(self):
-        return self.client_metadata.get('grant_types', [])
+        return self.client_metadata.get("grant_types", [])
 
     @property
     def response_types(self):
-        return self.client_metadata.get('response_types', [])
+        return self.client_metadata.get("response_types", [])
 
     @property
     def client_name(self):
-        return self.client_metadata.get('client_name')
+        return self.client_metadata.get("client_name")
 
     @property
     def client_uri(self):
-        return self.client_metadata.get('client_uri')
+        return self.client_metadata.get("client_uri")
 
     @property
     def logo_uri(self):
-        return self.client_metadata.get('logo_uri')
+        return self.client_metadata.get("logo_uri")
 
     @property
     def scope(self):
-        return self.client_metadata.get('scope', '')
+        return self.client_metadata.get("scope", "")
 
     @property
     def contacts(self):
-        return self.client_metadata.get('contacts', [])
+        return self.client_metadata.get("contacts", [])
 
     @property
     def tos_uri(self):
-        return self.client_metadata.get('tos_uri')
+        return self.client_metadata.get("tos_uri")
 
     @property
     def policy_uri(self):
-        return self.client_metadata.get('policy_uri')
+        return self.client_metadata.get("policy_uri")
 
     @property
     def jwks_uri(self):
-        return self.client_metadata.get('jwks_uri')
+        return self.client_metadata.get("jwks_uri")
 
     @property
     def jwks(self):
-        return self.client_metadata.get('jwks', [])
+        return self.client_metadata.get("jwks", [])
 
     @property
     def software_id(self):
-        return self.client_metadata.get('software_id')
+        return self.client_metadata.get("software_id")
 
     @property
     def software_version(self):
-        return self.client_metadata.get('software_version')
+        return self.client_metadata.get("software_version")
 
     def get_client_id(self):
         return self.client_id
@@ -114,7 +119,7 @@ class OAuth2ClientMixin(ClientMixin):
 
     def get_allowed_scope(self, scope):
         if not scope:
-            return ''
+            return ""
         allowed = set(self.scope.split())
         scopes = scope_to_list(scope)
         return list_to_scope([s for s in scopes if s in allowed])
@@ -122,14 +127,11 @@ class OAuth2ClientMixin(ClientMixin):
     def check_redirect_uri(self, redirect_uri):
         return redirect_uri in self.redirect_uris
 
-    def has_client_secret(self):
-        return bool(self.client_secret)
-
     def check_client_secret(self, client_secret):
         return secrets.compare_digest(self.client_secret, client_secret)
 
     def check_endpoint_auth_method(self, method, endpoint):
-        if endpoint == 'token':
+        if endpoint == "token":
             return self.token_endpoint_auth_method == method
         # TODO
         return True
