@@ -1,31 +1,37 @@
-from authlib.common.encoding import (
-    to_bytes,
-    to_unicode,
-    urlsafe_b64encode,
-    json_b64encode,
-)
-from authlib.jose.util import (
-    extract_header,
-    extract_segment, ensure_dict,
-)
-from authlib.jose.errors import (
-    DecodeError,
-    MissingAlgorithmError,
-    UnsupportedAlgorithmError,
-    BadSignatureError,
-    InvalidHeaderParameterNameError,
-)
-from .models import JWSHeader, JWSObject
+from authlib.common.encoding import json_b64encode
+from authlib.common.encoding import to_bytes
+from authlib.common.encoding import to_unicode
+from authlib.common.encoding import urlsafe_b64encode
+from authlib.jose.errors import BadSignatureError
+from authlib.jose.errors import DecodeError
+from authlib.jose.errors import InvalidHeaderParameterNameError
+from authlib.jose.errors import MissingAlgorithmError
+from authlib.jose.errors import UnsupportedAlgorithmError
+from authlib.jose.util import ensure_dict
+from authlib.jose.util import extract_header
+from authlib.jose.util import extract_segment
+
+from .models import JWSHeader
+from .models import JWSObject
 
 
-class JsonWebSignature(object):
-
+class JsonWebSignature:
     #: Registered Header Parameter Names defined by Section 4.1
-    REGISTERED_HEADER_PARAMETER_NAMES = frozenset([
-        'alg', 'jku', 'jwk', 'kid',
-        'x5u', 'x5c', 'x5t', 'x5t#S256',
-        'typ', 'cty', 'crit'
-    ])
+    REGISTERED_HEADER_PARAMETER_NAMES = frozenset(
+        [
+            "alg",
+            "jku",
+            "jwk",
+            "kid",
+            "x5u",
+            "x5c",
+            "x5t",
+            "x5t#S256",
+            "typ",
+            "cty",
+            "crit",
+        ]
+    )
 
     #: Defined available JWS algorithms in the registry
     ALGORITHMS_REGISTRY = {}
@@ -36,9 +42,8 @@ class JsonWebSignature(object):
 
     @classmethod
     def register_algorithm(cls, algorithm):
-        if not algorithm or algorithm.algorithm_type != 'JWS':
-            raise ValueError(
-                'Invalid algorithm for JWS, {!r}'.format(algorithm))
+        if not algorithm or algorithm.algorithm_type != "JWS":
+            raise ValueError(f"Invalid algorithm for JWS, {algorithm!r}")
         cls.ALGORITHMS_REGISTRY[algorithm.name] = algorithm
 
     def serialize_compact(self, protected, payload, key):
@@ -65,9 +70,9 @@ class JsonWebSignature(object):
         payload_segment = urlsafe_b64encode(to_bytes(payload))
 
         # calculate signature
-        signing_input = b'.'.join([protected_segment, payload_segment])
+        signing_input = b".".join([protected_segment, payload_segment])
         signature = urlsafe_b64encode(algorithm.sign(signing_input, key))
-        return b'.'.join([protected_segment, payload_segment, signature])
+        return b".".join([protected_segment, payload_segment, signature])
 
     def deserialize_compact(self, s, key, decode=None):
         """Exact JWS Compact Serialization, and validate with the given key.
@@ -84,10 +89,10 @@ class JsonWebSignature(object):
         """
         try:
             s = to_bytes(s)
-            signing_input, signature_segment = s.rsplit(b'.', 1)
-            protected_segment, payload_segment = signing_input.split(b'.', 1)
-        except ValueError:
-            raise DecodeError('Not enough segments')
+            signing_input, signature_segment = s.rsplit(b".", 1)
+            protected_segment, payload_segment = signing_input.split(b".", 1)
+        except ValueError as exc:
+            raise DecodeError("Not enough segments") from exc
 
         protected = _extract_header(protected_segment)
         jws_header = JWSHeader(protected, None)
@@ -97,7 +102,7 @@ class JsonWebSignature(object):
             payload = decode(payload)
 
         signature = _extract_signature(signature_segment)
-        rv = JWSObject(jws_header, payload, 'compact')
+        rv = JWSObject(jws_header, payload, "compact")
         algorithm, key = self._prepare_algorithm_key(jws_header, payload, key)
         if algorithm.verify(signing_input, signature, key):
             return rv
@@ -130,27 +135,24 @@ class JsonWebSignature(object):
             _alg, _key = self._prepare_algorithm_key(jws_header, payload, key)
 
             protected_segment = json_b64encode(jws_header.protected)
-            signing_input = b'.'.join([protected_segment, payload_segment])
+            signing_input = b".".join([protected_segment, payload_segment])
             signature = urlsafe_b64encode(_alg.sign(signing_input, _key))
 
             rv = {
-                'protected': to_unicode(protected_segment),
-                'signature': to_unicode(signature)
+                "protected": to_unicode(protected_segment),
+                "signature": to_unicode(signature),
             }
             if jws_header.header is not None:
-                rv['header'] = jws_header.header
+                rv["header"] = jws_header.header
             return rv
 
         if isinstance(header_obj, dict):
             data = _sign(JWSHeader.from_dict(header_obj))
-            data['payload'] = to_unicode(payload_segment)
+            data["payload"] = to_unicode(payload_segment)
             return data
 
         signatures = [_sign(JWSHeader.from_dict(h)) for h in header_obj]
-        return {
-            'payload': to_unicode(payload_segment),
-            'signatures': signatures
-        }
+        return {"payload": to_unicode(payload_segment), "signatures": signatures}
 
     def deserialize_json(self, obj, key, decode=None):
         """Exact JWS JSON Serialization, and validate with the given key.
@@ -165,10 +167,10 @@ class JsonWebSignature(object):
 
         .. _`Section 7.2`: https://tools.ietf.org/html/rfc7515#section-7.2
         """
-        obj = ensure_dict(obj, 'JWS')
+        obj = ensure_dict(obj, "JWS")
 
-        payload_segment = obj.get('payload')
-        if not payload_segment:
+        payload_segment = obj.get("payload")
+        if payload_segment is None:
             raise DecodeError('Missing "payload" value')
 
         payload_segment = to_bytes(payload_segment)
@@ -176,26 +178,28 @@ class JsonWebSignature(object):
         if decode:
             payload = decode(payload)
 
-        if 'signatures' not in obj:
+        if "signatures" not in obj:
             # flattened JSON JWS
             jws_header, valid = self._validate_json_jws(
-                payload_segment, payload, obj, key)
+                payload_segment, payload, obj, key
+            )
 
-            rv = JWSObject(jws_header, payload, 'flat')
+            rv = JWSObject(jws_header, payload, "flat")
             if valid:
                 return rv
             raise BadSignatureError(rv)
 
         headers = []
         is_valid = True
-        for header_obj in obj['signatures']:
+        for header_obj in obj["signatures"]:
             jws_header, valid = self._validate_json_jws(
-                payload_segment, payload, header_obj, key)
+                payload_segment, payload, header_obj, key
+            )
             headers.append(jws_header)
             if not valid:
                 is_valid = False
 
-        rv = JWSObject(headers, payload, 'json')
+        rv = JWSObject(headers, payload, "json")
         if is_valid:
             return rv
         raise BadSignatureError(rv)
@@ -214,7 +218,7 @@ class JsonWebSignature(object):
         """
         if isinstance(header, (list, tuple)):
             return self.serialize_json(header, payload, key)
-        if 'protected' in header:
+        if "protected" in header:
             return self.serialize_json(header, payload, key)
         return self.serialize_compact(header, payload, key)
 
@@ -235,15 +239,15 @@ class JsonWebSignature(object):
             return self.deserialize_json(s, key, decode)
 
         s = to_bytes(s)
-        if s.startswith(b'{') and s.endswith(b'}'):
+        if s.startswith(b"{") and s.endswith(b"}"):
             return self.deserialize_json(s, key, decode)
         return self.deserialize_compact(s, key, decode)
 
     def _prepare_algorithm_key(self, header, payload, key):
-        if 'alg' not in header:
+        if "alg" not in header:
             raise MissingAlgorithmError()
 
-        alg = header['alg']
+        alg = header["alg"]
         if self._algorithms is not None and alg not in self._algorithms:
             raise UnsupportedAlgorithmError()
         if alg not in self.ALGORITHMS_REGISTRY:
@@ -252,8 +256,8 @@ class JsonWebSignature(object):
         algorithm = self.ALGORITHMS_REGISTRY[alg]
         if callable(key):
             key = key(header, payload)
-        elif key is None and 'jwk' in header:
-            key = header['jwk']
+        elif key is None and "jwk" in header:
+            key = header["jwk"]
         key = algorithm.prepare_key(key)
         return algorithm, key
 
@@ -269,23 +273,23 @@ class JsonWebSignature(object):
                     raise InvalidHeaderParameterNameError(k)
 
     def _validate_json_jws(self, payload_segment, payload, header_obj, key):
-        protected_segment = header_obj.get('protected')
+        protected_segment = header_obj.get("protected")
         if not protected_segment:
             raise DecodeError('Missing "protected" value')
 
-        signature_segment = header_obj.get('signature')
+        signature_segment = header_obj.get("signature")
         if not signature_segment:
             raise DecodeError('Missing "signature" value')
 
         protected_segment = to_bytes(protected_segment)
         protected = _extract_header(protected_segment)
-        header = header_obj.get('header')
+        header = header_obj.get("header")
         if header and not isinstance(header, dict):
             raise DecodeError('Invalid "header" value')
 
         jws_header = JWSHeader(protected, header)
         algorithm, key = self._prepare_algorithm_key(jws_header, payload, key)
-        signing_input = b'.'.join([protected_segment, payload_segment])
+        signing_input = b".".join([protected_segment, payload_segment])
         signature = _extract_signature(to_bytes(signature_segment))
         if algorithm.verify(signing_input, signature, key):
             return jws_header, True
@@ -297,8 +301,8 @@ def _extract_header(header_segment):
 
 
 def _extract_signature(signature_segment):
-    return extract_segment(signature_segment, DecodeError, 'signature')
+    return extract_segment(signature_segment, DecodeError, "signature")
 
 
 def _extract_payload(payload_segment):
-    return extract_segment(payload_segment, DecodeError, 'payload')
+    return extract_segment(payload_segment, DecodeError, "payload")
