@@ -1,34 +1,34 @@
+import binascii
 import os
 import time
-import binascii
-from authlib.consts import default_json_headers
+
 from authlib.common.security import generate_token
-from authlib.jose import JsonWebToken, JoseError
-from ..rfc6749 import AccessDeniedError, InvalidRequestError
-from ..rfc6749 import scope_to_list
+from authlib.consts import default_json_headers
+from authlib.jose import JoseError
+from authlib.jose import JsonWebToken
+
+from ..rfc6749 import AccessDeniedError
+from ..rfc6749 import InvalidRequestError
 from .claims import ClientMetadataClaims
-from .errors import (
-    InvalidClientMetadataError,
-    UnapprovedSoftwareStatementError,
-    InvalidSoftwareStatementError,
-)
+from .errors import InvalidClientMetadataError
+from .errors import InvalidSoftwareStatementError
+from .errors import UnapprovedSoftwareStatementError
 
 
-class ClientRegistrationEndpoint(object):
+class ClientRegistrationEndpoint:
     """The client registration endpoint is an OAuth 2.0 endpoint designed to
     allow a client to be registered with the authorization server.
     """
-    ENDPOINT_NAME = 'client_registration'
 
-    #: The claims validation class
-    claims_class = ClientMetadataClaims
+    ENDPOINT_NAME = "client_registration"
 
     #: Rewrite this value with a list to support ``software_statement``
     #: e.g. ``software_statement_alg_values_supported = ['RS256']``
     software_statement_alg_values_supported = None
 
-    def __init__(self, server):
+    def __init__(self, server=None, claims_classes=None):
         self.server = server
+        self.claims_classes = claims_classes or [ClientMetadataClaims]
 
     def __call__(self, request):
         return self.create_registration_response(request)
@@ -56,18 +56,27 @@ class ClientRegistrationEndpoint(object):
             raise InvalidRequestError()
 
         json_data = request.data.copy()
-        software_statement = json_data.pop('software_statement', None)
+        software_statement = json_data.pop("software_statement", None)
         if software_statement and self.software_statement_alg_values_supported:
             data = self.extract_software_statement(software_statement, request)
             json_data.update(data)
 
-        options = self.get_claims_options()
-        claims = self.claims_class(json_data, {}, options, self.get_server_metadata())
-        try:
-            claims.validate()
-        except JoseError as error:
-            raise InvalidClientMetadataError(error.description)
-        return claims.get_registered_claims()
+        client_metadata = {}
+        server_metadata = self.get_server_metadata()
+        for claims_class in self.claims_classes:
+            options = (
+                claims_class.get_claims_options(server_metadata)
+                if server_metadata
+                else {}
+            )
+            claims = claims_class(json_data, {}, options, server_metadata)
+            try:
+                claims.validate()
+            except JoseError as error:
+                raise InvalidClientMetadataError(error.description) from error
+
+            client_metadata.update(**claims.get_registered_claims())
+        return client_metadata
 
     def extract_software_statement(self, software_statement, request):
         key = self.resolve_public_key(request)
@@ -79,51 +88,8 @@ class ClientRegistrationEndpoint(object):
             claims = jwt.decode(software_statement, key)
             # there is no need to validate claims
             return claims
-        except JoseError:
-            raise InvalidSoftwareStatementError()
-
-    def get_claims_options(self):
-        """Generate claims options validation from Authorization Server metadata."""
-        metadata = self.get_server_metadata()
-        if not metadata:
-            return {}
-
-        scopes_supported = metadata.get('scopes_supported')
-        response_types_supported = metadata.get('response_types_supported')
-        grant_types_supported = metadata.get('grant_types_supported')
-        auth_methods_supported = metadata.get('token_endpoint_auth_methods_supported')
-        options = {}
-        if scopes_supported is not None:
-            scopes_supported = set(scopes_supported)
-
-            def _validate_scope(claims, value):
-                if not value:
-                    return True
-                scopes = set(scope_to_list(value))
-                return scopes_supported.issuperset(scopes)
-
-            options['scope'] = {'validate': _validate_scope}
-
-        if response_types_supported is not None:
-            response_types_supported = set(response_types_supported)
-
-            def _validate_response_types(claims, value):
-                return response_types_supported.issuperset(set(value))
-
-            options['response_types'] = {'validate': _validate_response_types}
-
-        if grant_types_supported is not None:
-            grant_types_supported = set(grant_types_supported)
-
-            def _validate_grant_types(claims, value):
-                return grant_types_supported.issuperset(set(value))
-
-            options['grant_types'] = {'validate': _validate_grant_types}
-
-        if auth_methods_supported is not None:
-            options['token_endpoint_auth_method'] = {'values': auth_methods_supported}
-
-        return options
+        except JoseError as exc:
+            raise InvalidSoftwareStatementError() from exc
 
     def generate_client_info(self):
         # https://tools.ietf.org/html/rfc7591#section-3.2.1
@@ -141,7 +107,8 @@ class ClientRegistrationEndpoint(object):
     def generate_client_registration_info(self, client, request):
         """Generate ```registration_client_uri`` and ``registration_access_token``
         for RFC7592. This method returns ``None`` by default. Developers MAY rewrite
-        this method to return registration information."""
+        this method to return registration information.
+        """
         return None
 
     def create_endpoint_request(self, request):
@@ -157,7 +124,7 @@ class ClientRegistrationEndpoint(object):
         """Generate ``client_secret`` value. Developers MAY rewrite this method
         to use their own way to generate ``client_secret``.
         """
-        return binascii.hexlify(os.urandom(24)).decode('ascii')
+        return binascii.hexlify(os.urandom(24)).decode("ascii")
 
     def get_server_metadata(self):
         """Return server metadata which includes supported grant types,
@@ -170,7 +137,7 @@ class ClientRegistrationEndpoint(object):
         Developers MUST implement this method in subclass::
 
             def authenticate_token(self, request):
-                auth = request.headers.get('Authorization')
+                auth = request.headers.get("Authorization")
                 return get_token_by_auth(auth)
 
         :return: token instance
