@@ -1,20 +1,19 @@
 import time
-from django.db.models import (
-    Model,
-    CharField,
-    TextField,
-    BooleanField,
-    IntegerField,
-)
-from django.db.models import ForeignKey, CASCADE
+
 from django.contrib.auth.models import User
+from django.db.models import CASCADE
+from django.db.models import CharField
+from django.db.models import ForeignKey
+from django.db.models import IntegerField
+from django.db.models import Model
+from django.db.models import TextField
+
 from authlib.common.security import generate_token
-from authlib.oauth2.rfc6749 import (
-    ClientMixin,
-    TokenMixin,
-    AuthorizationCodeMixin,
-)
-from authlib.oauth2.rfc6749.util import scope_to_list, list_to_scope
+from authlib.oauth2.rfc6749 import AuthorizationCodeMixin
+from authlib.oauth2.rfc6749 import ClientMixin
+from authlib.oauth2.rfc6749 import TokenMixin
+from authlib.oauth2.rfc6749.util import list_to_scope
+from authlib.oauth2.rfc6749.util import scope_to_list
 
 
 def now_timestamp():
@@ -25,12 +24,12 @@ class Client(Model, ClientMixin):
     user = ForeignKey(User, on_delete=CASCADE)
     client_id = CharField(max_length=48, unique=True, db_index=True)
     client_secret = CharField(max_length=48, blank=True)
-    redirect_uris = TextField(default='')
-    default_redirect_uri = TextField(blank=False, default='')
-    scope = TextField(default='')
-    response_type = TextField(default='')
-    grant_type = TextField(default='')
-    token_endpoint_auth_method = CharField(max_length=120, default='')
+    redirect_uris = TextField(default="")
+    default_redirect_uri = TextField(blank=False, default="")
+    scope = TextField(default="")
+    response_type = TextField(default="")
+    grant_type = TextField(default="")
+    token_endpoint_auth_method = CharField(max_length=120, default="")
 
     def get_client_id(self):
         return self.client_id
@@ -40,7 +39,7 @@ class Client(Model, ClientMixin):
 
     def get_allowed_scope(self, scope):
         if not scope:
-            return ''
+            return ""
         allowed = set(scope_to_list(self.scope))
         return list_to_scope([s for s in scope.split() if s in allowed])
 
@@ -53,7 +52,7 @@ class Client(Model, ClientMixin):
         return self.client_secret == client_secret
 
     def check_endpoint_auth_method(self, method, endpoint):
-        if endpoint == 'token':
+        if endpoint == "token":
             return self.token_endpoint_auth_method == method
         return True
 
@@ -72,7 +71,7 @@ class OAuth2Token(Model, TokenMixin):
     token_type = CharField(max_length=40)
     access_token = CharField(max_length=255, unique=True, null=False)
     refresh_token = CharField(max_length=255, db_index=True)
-    scope = TextField(default='')
+    scope = TextField(default="")
 
     issued_at = IntegerField(null=False, default=now_timestamp)
     expires_in = IntegerField(null=False, default=0)
@@ -106,9 +105,9 @@ class OAuth2Code(Model, AuthorizationCodeMixin):
     user = ForeignKey(User, on_delete=CASCADE)
     client_id = CharField(max_length=48, db_index=True)
     code = CharField(max_length=120, unique=True, null=False)
-    redirect_uri = TextField(default='', null=True)
-    response_type = TextField(default='')
-    scope = TextField(default='', null=True)
+    redirect_uri = TextField(default="", null=True)
+    response_type = TextField(default="")
+    scope = TextField(default="", null=True)
     auth_time = IntegerField(null=False, default=now_timestamp)
 
     def is_expired(self):
@@ -118,7 +117,7 @@ class OAuth2Code(Model, AuthorizationCodeMixin):
         return self.redirect_uri
 
     def get_scope(self):
-        return self.scope or ''
+        return self.scope or ""
 
     def get_auth_time(self):
         return self.auth_time
@@ -150,7 +149,7 @@ def generate_authorization_code(client, grant_user, request, **extra):
         response_type=request.response_type,
         scope=request.scope,
         user=grant_user,
-        **extra
+        **extra,
     )
     item.save()
     return code
